@@ -148,19 +148,38 @@ def read_info(input_dics):
     :param input_dics:
     :return:
     """
-    evs_info = locate(input_dics['datapath'], 'EVENTS-INFO')
+    evs_info = locate(input_dics['datapath'], 'EVENTS-INFO', num_matches=1)
     if len(evs_info) == 0:
         return "no_local"
     if len(evs_info) > 1:
-        print("[WARNING] Found two directories that have EVENTS-INFO. " \
-              "Continue with:")
+        print("[WARNING] Found two directories that have EVENTS-INFO. Continue with:")
         print(evs_info[0])
         print('\n')
 
     ev_info = evs_info[0]
 
     if not os.path.isfile(os.path.join(ev_info, 'event_list_pickle')):
-        return "no_local"
+        print("[WARNING] no 'event_list_pickle' was found at %s, "
+              "try to re-generate it..." % ev_info)
+        info_dirs = locate(input_dics['datapath'], 'info')
+        event_list_regen = []
+        for info_d in info_dirs:
+            if os.path.isfile(os.path.join(info_d, 'event.pkl')):
+                try:
+                    ev_pkl_tmp = pickle.load(open(os.path.join(info_d, 'event.pkl'), 'r'))
+                    # to check whether t1 and t2 variables are there:
+                    test_t1 = ev_pkl_tmp['t1']
+                    test_t2 = ev_pkl_tmp['t2']
+                    event_list_regen.append(ev_pkl_tmp)
+                except Exception as e:
+                    print("ERROR: %s" % e)
+        if len(event_list_regen) > 0:
+            print("[WARNING] a new 'event_list_pickle' was generated with %s events." % len(event_list_regen))
+            fio = open(os.path.join(ev_info, 'event_list_pickle'), 'w')
+            pickle.dump(event_list_regen, fio, protocol=2)
+        else:
+            print("[WARNING] a new 'event_list_pickle' could NOT be generated.")
+            return "no_local"
 
     fio = open(os.path.join(ev_info, 'event_list_pickle'), 'rb')
     events = pickle.load(fio)
@@ -786,7 +805,7 @@ def gcmt_catalog(t_start, t_end, min_latitude, max_latitude, min_longitude,
 
     # creating a time list
     t_list = []
-    delta_t = int(UTCDateTime(t_end)-UTCDateTime(t_start)+1)/86400
+    delta_t = int(int(UTCDateTime(t_end)-UTCDateTime(t_start)+1)/86400)
 
     yymm = []
     for i in range(delta_t + 1):
@@ -829,13 +848,26 @@ def gcmt_catalog(t_start, t_end, min_latitude, max_latitude, min_longitude,
                                             '%s.qml' % yy)
             if not os.path.exists(file_to_open) and not new_monthly == 'COMBO':
                 print('Reading the data from GCMT webpage: %s' % yymmls[i])
+                if not os.path.isdir(os.path.join(gcmt_cat_path, new_monthly)):
+                    print('Create: %s' % os.path.join(gcmt_cat_path, new_monthly))
+                    os.makedirs(os.path.join(gcmt_cat_path, new_monthly))
                 remotefile = urlopen(remotefile_add)
                 remotefile_read = remotefile.readlines()
-                search_fio = open(file_to_open, 'w')
+                search_fio = open(file_to_open, 'wb')
                 search_fio.writelines(remotefile_read)
                 search_fio.close()
-            print('Reading the data from local gcmt_catalog: %s' % yymmls[i])
-            cat.extend(readEvents(file_to_open))
+            if (not os.path.exists(file_to_open)) and (new_monthly == 'COMBO'):
+                if not os.path.isdir(os.path.join(gcmt_cat_path, new_monthly)):
+                    print('Create: %s' % os.path.join(gcmt_cat_path, new_monthly))
+                    os.makedirs(os.path.join(gcmt_cat_path, new_monthly))
+                print('WARNING: The following file does not exist: %s' % file_to_open)
+                print('WARNING: Reading data from GCMT webpage: %s' % ('http://www.ldeo.columbia.edu/~gcmt/projects/CMT/catalog/COMBO/combo.ndk'))
+                print('WARNING: This will take a very long time, refer to:')
+                print('https://github.com/kasra-hosseini/obspyDMT/tree/master/obspyDMT/gcmt_catalog/COMBO')
+                cat = readEvents('http://www.ldeo.columbia.edu/~gcmt/projects/CMT/catalog/COMBO/combo.ndk')
+            else:
+                print('Reading the data from local gcmt_catalog: %s' % yymmls[i])
+                cat.extend(readEvents(file_to_open))
             yy_ret.append(yy)
             mm_ret.append(mm)
         except Exception as error:
@@ -1276,14 +1308,26 @@ def write_cat_logger(input_dics, eventpath, events, catalog,
 
     # output catalogue as QUAKEML / JSON files
     try:
-        catalog.write(os.path.join(eventpath, 'EVENTS-INFO', 'catalog.ml'),
-                      format="QUAKEML")
+        if not input_dics['event_catalog'].lower() == 'local':
+            if os.path.isfile(os.path.join(eventpath, 'EVENTS-INFO', 'catalog.ml')):
+                stored_catalog = Catalog(events=[])
+                try:
+                    stored_catalog = readEvents(os.path.join(eventpath, 'EVENTS-INFO',
+                                                'catalog.ml'), format="QUAKEML")
+                except Exception as err:
+                    pass
+                for stored_ev in stored_catalog:
+                    if not stored_ev in catalog:
+                        catalog.append(stored_ev)
+            catalog.write(os.path.join(eventpath, 'EVENTS-INFO', 'catalog.ml'),
+                          format="QUAKEML")
     except Exception as err:
         print('\nCouldn\'t write catalog object to QuakeML as:\n>>:\t %s\n' \
               'Proceed without ..\n' % err)
     try:
-        catalog.write(os.path.join(eventpath, 'EVENTS-INFO', 'catalog.zmap'),
-                      format="ZMAP")
+        if not input_dics['event_catalog'].lower() == 'local':
+            catalog.write(os.path.join(eventpath, 'EVENTS-INFO', 'catalog.zmap'),
+                          format="ZMAP")
     except Exception as err:
         print('\nCouldn\'t write catalog object to JSON as:\n>>:\t %s\n' \
               'Proceed without ..\n' % err)
@@ -1303,7 +1347,7 @@ def sort_catalogue(cat):
     cat = Catalog(events=events)
     return cat
 
-# ##################### mag_halfduration ###################################
+# ##################### mag_duration ###################################
 
 
 def mag_duration(mag, type_curve=1):
