@@ -69,7 +69,7 @@ def command_parse():
     group_path.add_option("--datapath", action="store",
                           dest="datapath", help=helpmsg)
 
-    helpmsg = "If the datapath is found, delet it before running obspyDMT."
+    helpmsg = "If the datapath is found, delete it before running obspyDMT."
     group_path.add_option("--reset", action="store_true",
                           dest="reset", help=helpmsg)
     parser.add_option_group(group_path)
@@ -197,7 +197,8 @@ def command_parse():
               "by --cut_time_phase. " \
               "In continuous mode, the reference time(s) are specified by " \
               "--interval option, and --offset appends " \
-              "the specified offset to each interval (default: 1800). " \
+              "the specified offset to each interval "\
+              "(default: 1800 for event-based mode and 0 for continuous mode). " \
               "Example: 3600"
     group_tw.add_option("--offset", action="store",
                         dest="offset", help=helpmsg)
@@ -311,15 +312,40 @@ def command_parse():
 
     # --------------- restricted data ---------------------------------
     group_restrict = OptionGroup(parser, "08. restricted data")
-    helpmsg = "Username for restricted data requests, " \
+    helpmsg = "Username for restricted FDSN data requests, " \
               "waveform/response modes (default: None)."
-    group_restrict.add_option("--user", action="store",
-                              dest="username", help=helpmsg)
+    group_restrict.add_option("--username_fdsn", action="store",
+                              dest="username_fdsn", help=helpmsg)
 
-    helpmsg = "Password for restricted data requests, " \
+    helpmsg = "Password for restricted FDSN data requests, " \
               "waveform/response modes (default: None)."
-    group_restrict.add_option("--pass", action="store",
-                              dest="password", help=helpmsg)
+    group_restrict.add_option("--password_fdsn", action="store",
+                              dest="password_fdsn", help=helpmsg)
+
+    helpmsg = "Username for restricted ArcLink data requests, " \
+              "waveform/response modes (default: 'test@obspy.org')."
+    group_restrict.add_option("--username_arclink", action="store",
+                              dest="username_arclink", help=helpmsg)
+
+    helpmsg = "Password for restricted ArcLink data requests, " \
+              "waveform/response modes (default: '')."
+    group_restrict.add_option("--password_arclink", action="store",
+                              dest="password_arclink", help=helpmsg)
+
+    helpmsg = "Host name of the remote ArcLink server, " \
+              "waveform/response modes, " \
+              "currently supports (Port is stated in the parenthesis, see --port_arclink option) " \
+              "webdc.eu (18001), webdc.eu (18002), eida.knmi.nl (18002), " \
+              "eida.gfz-potsdam.de (18001), eida.resif.fr (18001), eida.ethz.ch (18001), " \
+              "eida.bgr.de (18001), eida.ipgp.fr (18001), seisrequest.iag.usp.br (18001), " \
+              "(default: 'webdc.eu')."
+    group_restrict.add_option("--host_arclink", action="store",
+                              dest="host_arclink", help=helpmsg)
+
+    helpmsg = "Port of the remote ArcLink server, " \
+              "waveform/response modes (default: '18002')."
+    group_restrict.add_option("--port_arclink", action="store",
+                              dest="port_arclink", help=helpmsg)
     parser.add_option_group(group_restrict)
 
     # --------------- event_based mode ----------------------------------------
@@ -555,19 +581,31 @@ def command_parse():
     group_plt.add_option("--plot_dir_name", action="store",
                          dest="plot_dir_name", help=helpmsg)
 
-    helpmsg = "Path where plots will be store " \
-              "(default: '.', i.e., the current directory)."
+    helpmsg = "Path and filename.format of a plot " \
+              "(default: './waveforms.png' for --plot_waveform, " \
+              "'./seismicity.png' for seismicity maps, " \
+              "'./event_station.png' for event/station/ray/... plots)."
     group_plt.add_option("--plot_save", action="store",
                          dest="plot_save", help=helpmsg)
 
-    helpmsg = "Image format of plots (default: 'png')."
+    helpmsg = "Image format of plots (default: 'png'). " \
+              "Note: DEPRECATED, specify the format directly in --plot_save."
     group_plt.add_option("--plot_format", action="store",
                          dest="plot_format", help=helpmsg)
 
+    helpmsg = "Don't show the plot, only save it at --plot_save path."
+    group_plt.add_option("--show_no_plot", action="store_true",
+                         dest="show_no_plot", help=helpmsg)
+
     helpmsg = "Central meridian (x-axis origin) for projection (default: 180)."
     group_plt.add_option("--plot_lon0", action="store",
                          dest="plot_lon0", help=helpmsg)
 
+    helpmsg = "Map style, 'simple', 'shadedrelief', 'etopo', 'bluemarble'. " \
+              "Note: PIL needs to be installed for all styles except 'simple'. (default: 'simple')"
+    group_plt.add_option("--plot_style", action="store",
+                         dest="plot_style", help=helpmsg)
+
     parser.add_option_group(group_plt)
 
     # --------------- explore instrument responses (stationXML files)
@@ -700,7 +738,7 @@ def read_input_command(parser, **kwargs):
                   # 'min_date': str(UTCDateTime() - 60 * 60 * 24 * 10 * 1),
                   'min_date': str(UTCDateTime(1970, 1, 1)),
                   'max_date': str(UTCDateTime()),
-                  'preset': 0.0, 'offset': 1800.0,
+                  'preset': 0.0, 'offset': False,
                   'waveform_format': False,
                   'resample_method': 'lanczos',
                   'sampling_rate': False,
@@ -714,8 +752,13 @@ def read_input_command(parser, **kwargs):
                   'req_np': 4,
                   'process_np': 4,
 
-                  'username': None,
-                  'password': None,
+                  'username_fdsn': None,
+                  'password_fdsn': None,
+
+                  'username_arclink': 'test@obspy.org',
+                  'password_arclink': '',
+                  'host_arclink': 'webdc.eu',
+                  'port_arclink': 18002,
 
                   'event_catalog': 'LOCAL',
                   'min_depth': -10.0, 'max_depth': +6000.0,
@@ -739,8 +782,9 @@ def read_input_command(parser, **kwargs):
 
                   'depth_bins_seismicity': 10,
                   'plot_dir_name': 'raw',
-                  'plot_save': '.', 'plot_format': 'png',
+                  'plot_save': False, 'plot_format': False,
                   'plot_lon0': 180,
+                  'plot_style': 'simple',
 
                   'plotxml_date': False,
                   'plotxml_start_stage': 1,
@@ -828,7 +872,7 @@ def read_input_command(parser, **kwargs):
         print(parser.option_groups[int(options.list_option)-1].title)
         for opt_grp in \
                 parser.option_groups[int(options.list_option)-1].option_list:
-            print("{0:20s}\t{1:20s}\t{2:20s}\t\t{3:20s}".\
+            print("{0:20s}\t{1:20s}\t{2!s:20}\t\t{3:20s}".\
                 format(opt_grp.get_opt_string(), opt_grp.dest,
                        opt_grp.type, opt_grp.help))
         sys.exit()
@@ -837,7 +881,7 @@ def read_input_command(parser, **kwargs):
     if options.version:
         print('\n\t\t' + '*********************************')
         print('\t\t' + '*        obspyDMT version:      *')
-        print('\t\t' + '*\t' + 5*' ' + '2.0.6' + '\t\t*')
+        print('\t\t' + '*\t' + 5*' ' + '2.2.3' + '\t\t*')
         print('\t\t' + '*********************************')
         print('\n')
         sys.exit(2)
@@ -964,10 +1008,14 @@ def read_input_command(parser, **kwargs):
     # =================== Data sources
     input_dics['data_source'] = options.data_source
     if input_dics['data_source'].lower() == 'all':
-        input_dics['data_source'] = \
-                "BGR,EMSC,ETH,GEONET,GFZ,INGV,IPGP,IRIS," \
-                "ISC,KOERI,LMU,NCEDC,NIEP,NOA,ODC,ORFEUS," \
-                "RESIF,SCEDC,USGS,USP,ARCLINK"
+        try:
+            from obspy.clients.fdsn import URL_MAPPINGS
+        except:
+            from obspy.fdsn.header import URL_MAPPINGS
+        input_dics['data_source'] = ''
+        for umap in URL_MAPPINGS.keys():
+            input_dics['data_source'] += str(umap) + ','
+        input_dics['data_source'] = input_dics['data_source'][:-1]
         print("\n=================================")
         print("Waveforms will be retrieved from:")
         print(input_dics['data_source'])
@@ -1018,14 +1066,21 @@ def read_input_command(parser, **kwargs):
     else:
         input_dics['max_azi'] = False
 
-    if options.test:
+    if (not options.test) or (options.test.lower() in ['false']):
+        pass
+    else:
         input_dics['test'] = True
         input_dics['test_num'] = int(options.test)
 
     input_dics['min_date'] = str(UTCDateTime(options.min_date))
     input_dics['max_date'] = str(UTCDateTime(options.max_date))
     input_dics['preset'] = float(options.preset)
-    input_dics['offset'] = float(options.offset)
+    if options.offset:
+        input_dics['offset'] = float(options.offset)
+    elif options.continuous:
+        input_dics['offset'] = 0.
+    else:
+        input_dics['offset'] = 1800.
 
     input_dics['cut_time_phase'] = options.cut_time_phase
 
@@ -1104,8 +1159,13 @@ def read_input_command(parser, **kwargs):
     input_dics['parallel_process'] = options.parallel_process
     input_dics['process_np'] = int(options.process_np)
 
-    input_dics['username'] = options.username
-    input_dics['password'] = options.password
+    input_dics['username_fdsn'] = options.username_fdsn
+    input_dics['password_fdsn'] = options.password_fdsn
+
+    input_dics['username_arclink'] = options.username_arclink
+    input_dics['password_arclink'] = options.password_arclink
+    input_dics['host_arclink'] = options.host_arclink
+    input_dics['port_arclink'] = int(options.port_arclink)
 
     if options.event_catalog:
         input_dics['event_catalog'] = options.event_catalog.upper()
@@ -1212,7 +1272,17 @@ def read_input_command(parser, **kwargs):
     input_dics['plot_dir_name'] = options.plot_dir_name
     input_dics['plot_save'] = options.plot_save
     input_dics['plot_format'] = options.plot_format
+    if input_dics['plot_format']:
+        print('DEPRECATED option: specify the image format directly in --plot_save.')
+    input_dics['show_no_plot'] = options.show_no_plot
+
     input_dics['plot_lon0'] = float(options.plot_lon0)
+    input_dics['plot_style'] = options.plot_style
+
+    if not input_dics['plot_style'] in ['simple', 'shadedrelief', 'etopo', 'bluemarble']:
+        print("Erroneous --plot_style given: %s\n"
+              "Available options: 'simple' or 'shadedrelief' or 'etopo' or 'bluemarble'" % input_dics['plot_style'])
+        sys.exit(2)
 
     if input_dics['plot']:
         input_dics['pre_process'] = False
