@@ -16,7 +16,6 @@ from __future__ import (absolute_import, division, print_function,
                         unicode_literals)
 from builtins import input as raw_input_built
 import matplotlib.pyplot as plt
-from mpl_toolkits.basemap import Basemap
 import multiprocessing
 import numpy as np
 try:
@@ -52,7 +51,7 @@ def process_data(input_dics, event):
     :param event:
     :return:
     """
-    target_path = locate(input_dics['datapath'], event['event_id'])
+    target_path = locate(input_dics['datapath'], event['event_id'], num_matches=1)
 
     if len(target_path) == 0:
         return
@@ -262,13 +261,29 @@ def plot_filter_event(input_dics, event_dic):
             if not event_dic['depth'] >= float(input_dics['min_depth']):
                 return False
             if isinstance(input_dics['evlatmin'], float):
+
+                if float(event_dic['longitude']) < 0:
+                    event_dic_360 = 360. + float(event_dic['longitude'])
+                else:
+                    event_dic_360 = float(event_dic['longitude'])
+
+                if float(input_dics['evlonmin']) < 0:
+                    evlonmin_360 = 360. + float(input_dics['evlonmin'])
+                else:
+                    evlonmin_360 = float(input_dics['evlonmin'])
+
+                if float(input_dics['evlonmax']) < 0:
+                    evlonmax_360 = 360. + float(input_dics['evlonmax'])
+                else:
+                    evlonmax_360 = float(input_dics['evlonmax'])
+
                 if not event_dic['latitude'] <= float(input_dics['evlatmax']):
                     return False
-                if not event_dic['longitude'] <= float(input_dics['evlonmax']):
+                if not event_dic_360 <= evlonmax_360:
                     return False
                 if not event_dic['latitude'] >= float(input_dics['evlatmin']):
                     return False
-                if not event_dic['longitude'] >= float(input_dics['evlonmin']):
+                if not event_dic_360 >= evlonmin_360:
                     return False
         return True
     except Exception as error:
@@ -286,7 +301,7 @@ def plot_waveform(input_dics, events):
     """
     # plt.rc('font', family='serif')
     for ei in range(len(events)):
-        target_path = locate(input_dics['datapath'], events[ei]['event_id'])
+        target_path = locate(input_dics['datapath'], events[ei]['event_id'], num_matches=1)
         if len(target_path) == 0:
             continue
         if len(target_path) > 1:
@@ -352,9 +367,12 @@ def plot_waveform(input_dics, events):
     plt.xticks(size=18)
     plt.yticks(size=18)
     plt.tight_layout()
-    plt.savefig(os.path.join(input_dics['plot_save'],
-                             'waveforms.%s' % input_dics['plot_format']))
-    plt.show()
+    if not input_dics['plot_save']:
+        plt.savefig(os.path.join(os.path.curdir, 'waveforms.png'))
+    else:
+        plt.savefig(os.path.join(input_dics['plot_save']))
+    if not input_dics['show_no_plot']:
+        plt.show()
 
 # ##################### plot_sta_ev_ray ###############################
 
@@ -366,6 +384,9 @@ def plot_sta_ev_ray(input_dics, events):
     :param events:
     :return:
     """
+
+    from mpl_toolkits.basemap import Basemap
+
     plt.figure(figsize=(20., 10.))
     plt_stations = input_dics['plot_sta']
     plt_availability = input_dics['plot_availability']
@@ -414,16 +435,11 @@ def plot_sta_ev_ray(input_dics, events):
     else:
         sys.exit('[ERROR] can not continue, error:\n%s' % input_dics)
 
-    raw_input_resp = raw_input_built('choose the map style:\n'
-                                     '1. bluemarble (PIL should be installed)\n'
-                                     '2. etopo (PIL should be installed)\n'
-                                     '3. shadedrelief (PIL should be installed)\n'
-                                     '4. simple\n')
-    if int(raw_input_resp) == 1:
+    if input_dics['plot_style'] == 'bluemarble':
         m.bluemarble(scale=0.5)
-    elif int(raw_input_resp) == 2:
+    elif input_dics['plot_style'] == 'etopo':
         m.etopo(scale=0.5)
-    elif int(raw_input_resp) == 3:
+    elif input_dics['plot_style'] == 'shadedrelief':
         m.shadedrelief(scale=0.1)
     else:
         m.fillcontinents()
@@ -460,7 +476,7 @@ def plot_sta_ev_ray(input_dics, events):
                           zorder=5, alpha=0.65)
         if plt_stations or plt_availability or plt_ray_path:
             target_path = locate(input_dics['datapath'],
-                                 events[ei]['event_id'])
+                                 events[ei]['event_id'], num_matches=1)
             if len(target_path) == 0:
                 continue
             if len(target_path) > 1:
@@ -557,9 +573,12 @@ def plot_sta_ev_ray(input_dics, events):
                                       float(sta_ev_arr[si][4]),
                                       color='k', alpha=0.1)
 
-    plt.savefig(os.path.join(input_dics['plot_save'],
-                             'event_station.%s' % input_dics['plot_format']))
-    plt.show()
+    if not input_dics['plot_save']:
+        plt.savefig(os.path.join(os.path.curdir, 'event_station.png'))
+    else:
+        plt.savefig(os.path.join(input_dics['plot_save']))
+    if not input_dics['show_no_plot']:
+        plt.show()
 
 # ##################### plot_seismicity #######################################
 
@@ -575,6 +594,8 @@ def plot_seismicity(input_dics, events):
     print('Seismicity map')
     print('==============\n')
 
+    from mpl_toolkits.basemap import Basemap
+
     # plt.rc('font', family='serif')
     if not len(events) > 0:
         print("[WARNING] no event passed the given criteria!")
@@ -604,16 +625,11 @@ def plot_seismicity(input_dics, events):
     meridians = np.arange(-180., 180., 60.)
     m.drawmeridians(meridians, fontsize=24)
 
-    raw_input_resp = raw_input_built('choose the map style:\n'
-                                     '1. bluemarble (PIL should be installed)\n'
-                                     '2. etopo (PIL should be installed)\n'
-                                     '3. shadedrelief (PIL should be installed)\n'
-                                     '4. simple\n')
-    if int(raw_input_resp) == 1:
+    if input_dics['plot_style'] == 'bluemarble':
         m.bluemarble(scale=0.5)
-    elif int(raw_input_resp) == 2:
+    elif input_dics['plot_style'] == 'etopo':
         m.etopo(scale=0.5)
-    elif int(raw_input_resp) == 3:
+    elif input_dics['plot_style'] == 'shadedrelief':
         m.shadedrelief(scale=0.1)
     else:
         m.fillcontinents()
@@ -715,11 +731,11 @@ def plot_seismicity(input_dics, events):
         meridians = np.arange(-180., 180., 60.)
         m.drawmeridians(meridians, fontsize=24)
 
-        if int(raw_input_resp) == 1:
+        if input_dics['plot_style'] == 'bluemarble':
             m.bluemarble(scale=0.5)
-        elif int(raw_input_resp) == 2:
+        elif input_dics['plot_style'] == 'etopo':
             m.etopo(scale=0.5)
-        elif int(raw_input_resp) == 3:
+        elif input_dics['plot_style'] == 'shadedrelief':
             m.shadedrelief(scale=0.1)
         else:
             m.fillcontinents()
@@ -773,7 +789,12 @@ def plot_seismicity(input_dics, events):
         plt.tight_layout()
         plt.grid(True)
 
-    plt.show()
+    if not input_dics['plot_save']:
+        plt.savefig(os.path.join(os.path.curdir, 'seismicity.png'))
+    else:
+        plt.savefig(os.path.join(input_dics['plot_save']))
+    if not input_dics['show_no_plot']:
+        plt.show()
 
 # ##################### vtk_generator ###################################
 
