@@ -75,11 +75,11 @@ def goodbye_printer(input_dics, t1_pro):
     print("\n\n==================================================")
     print("obspyDMT main program has finished!\n")
     try:
-        size = getFolderSize(input_dics['datapath'])
-        size /= (1024.**2)
-        print("Info:")
-        print("* The directory contains %s MB of data." \
-              % "{:.3f}".format(float(size)))
+        #size = getFolderSize(input_dics['datapath'])
+        #size /= (1024.**2)
+        #print("Info:")
+        #print("* The directory contains %s MB of data." \
+        #      % "{:.3f}".format(float(size)))
         print(input_dics['datapath'])
         print("* Total time of execution: %s (h:m:s)" \
               % str(timedelta(seconds=round(float(time.time() - t1_pro)))))
@@ -405,17 +405,21 @@ def create_station_event(address):
 # ##################### locate ##########################################
 
 
-def locate(root='.', target='info'):
+def locate(root='.', target='info', num_matches=-1):
     """
     locates a subdirectory within a directory
     :param root:
     :param target:
+    :param num_matches:
     :return:
     """
     matches = []
     for root, dirnames, filenames in os.walk(root):
         for dirname in fnmatch.filter(dirnames, target):
             matches.append(os.path.join(root, dirname))
+        if num_matches > 0:
+            if len(matches) >= num_matches:
+                break
 
     return matches
 
